import * as _vue from "vue";
import AModal from 'ant-design-vue/es/modal';
import { ImageProps } from './types';
import ELoading from '../Loading';
import './style.less';
/**
 * 图片组件
 */

export default {
  name: 'EImage',
  components: {
    AModal: AModal,
    ELoading: ELoading
  },
  props: ImageProps,
  data: function data() {
    return {
      previewModalVisible: false,
      // 预览模态是否显示
      isLoading: true,
      // 是否在加载中
      loadImageSuccess: false
    };
  },
  methods: {
    /**
     * 获取图片的显示绝对路径
     * @returns {*}
     * @private
     */
    _getImageTargetUrl: function _getImageTargetUrl() {
      return this.$props.url;
    },

    /**
     * loading结束
     * @param loadImageSuccess 图片加载是否成功
     * @private
     */
    _loadingFinish: function _loadingFinish() {
      var loadImageSuccess = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;

      if (this.$data.isLoading) {
        this.$data.isLoading = false;
        this.$data.loadImageSuccess = loadImageSuccess;
      }
    },

    /**
     * 预览图片
     */
    previewImage: function previewImage() {
      this.$data.previewModalVisible = true;
    },

    /**
     * 隐藏预览
     */
    hidePreview: function hidePreview() {
      this.$data.previewModalVisible = false;
    },

    /**
     * 渲染预览的模态
     * @return {*}
     */
    renderPreviewModal: function renderPreviewModal() {
      var _this = this;

      var props = {
        visible: this.$data.previewModalVisible,
        footer: null,
        maskClosable: true,
        width: '960px'
      };
      return _vue.createVNode(_vue.resolveComponent("a-modal"), _vue.mergeProps({
        props: props
      }, {
        "onCancel": this.hidePreview
      }), {
        "default": function _default() {
          return [_vue.createVNode("div", {
            "class": "preview-img-wrapper"
          }, [_vue.createVNode("img", {
            "src": _this._getImageTargetUrl(),
            "class": "preview-img",
            "alt": ""
          }, null)])];
        }
      });
    }
  },
  render: function render() {
    var _this2 = this;

    var clickToPreview = this.$props.clickToPreview;
    var showDom = null;

    if (this.$data.isLoading) {
      // 展示loading
      showDom = [_vue.createVNode(_vue.resolveComponent("e-loading"), null, null), _vue.createVNode("img", {
        "class": "loading-img",
        "src": this._getImageTargetUrl(),
        "onLoad": function onLoad() {
          _this2._loadingFinish();
        }
      }, null)];
    } else if (this.$data.loadImageSuccess) {
      return _vue.createVNode("div", {
        "class": "oss-image-wrapper",
        "onClick": this.previewImage
      }, [_vue.createVNode("img", {
        "src": this._getImageTargetUrl()
      }, null), clickToPreview ? this.renderPreviewModal() : null]);
    } else {
      showDom = '图片加载失败';
    }

    return _vue.createVNode("div", {
      "class": "oss-image-wrapper"
    }, [showDom]);
  }
};